==> haskell-uri-bytestring-0.3.3.1-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-GiKcvXXBrWqCWldQZ8Mir6
key:                  uri-bytestring-0.3.3.1-GiKcvXXBrWqCWldQZ8Mir6
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  000e86b093f04965e2f4dee7c92cf148
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-GiKcvXXBrWqCWldQZ8Mir6
depends:
    attoparsec-0.14.4-5wZOVAk6w2AKDrkEEe6wrE base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 template-haskell-2.18.0.0
    th-lift-instances-0.1.20-B3Kq1iep7z07arJmqpH6j5

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.3.1-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-JdHWbnLKxRl6GjsI542XEd
key:                  uri-bytestring-0.3.3.1-JdHWbnLKxRl6GjsI542XEd
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  fbac3041713434a197af7d6d95790b77
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-JdHWbnLKxRl6GjsI542XEd
depends:
    attoparsec-0.14.4-3uzSp4DJeNe8DMv46inf7D base-4.16.4.0
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    containers-0.6.5.1 template-haskell-2.18.0.0
    th-lift-instances-0.1.20-I1ygmSLlmAPD8XTinnmAx3

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
